Git-based Config Context - Nautobot Design Builder Documentation

Skip to content

# Git-based Config Context

Design Builder is capable of generating config contexts for devices based on Jinja templates. The config contexts can either be stored directly in the Nautobot database, or they can be added to a config context git repository. This document covers storing the generated config contexts in a git repository.

More background information on config contexts can be found in the official Nautobot documentation.

Before this capability can be used, Nautobot must be configured with a Git repository set to include `Config Contexts` (see the official documentation).

Additionally, the design builder needs to be configured for Git contexts. In order to configure design_builder update `PLUGIN_CONFIG` in `nautobot_config.py` and set the `context_repository` configuration setting to the `slug` of the configured context repository:

    PLUGINS_CONFIG = {
        "design_builder": {
            "context_repository": "slug-of-the-git-repo"
        }
    }